@@ -1,5 +1,5 @@
 from .ai_model import *
-from .analytics import *
+from .ai_analytics import *
 from .content_assistant import *
 from .entities import *
 from .intents import *
