@@ -2,8 +2,8 @@ from __future__ import annotations
 from dataclasses import dataclass, field
 from typing import TYPE_CHECKING
 
+from .ai_analytics import AiAnalyticsExtension
 from .ai_model import AiModelExtension
-from .analytics import AnalyticsExtension
 from .content_assistant import ContentAssistantExtension
 from .entities import EntitiesExtension
 from .intents import IntentsExtension
@@ -20,7 +20,7 @@ class AiExtension:
     client: Client
     to: str
     ai_model: AiModelExtension = field(init=False)
-    analytics: AnalyticsExtension = field(init=False)
+    analytics: AiAnalyticsExtension = field(init=False)
     content_assistant: ContentAssistantExtension = field(init=False)
     entities: EntitiesExtension = field(init=False)
     intents: IntentsExtension = field(init=False)
@@ -28,7 +28,7 @@ class AiExtension:
 
     def __post_init__(self) -> None:  # noqa: D105
         self.ai_model = AiModelExtension(self.client, self.to)
-        self.analytics = AnalyticsExtension(self.client, self.to)
+        self.analytics = AiAnalyticsExtension(self.client, self.to)
         self.content_assistant = ContentAssistantExtension(
             self.client,
             self.to
